Installation — IoC 0.0.15 documentation

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »

# Installation

First, obtain Python and virtualenv if you do not already have them. Using a virtual environment will make the installation easier, and will help to avoid clutter in your system-wide libraries. You will also need Git in order to clone the repository.

Once you have these, create a virtual environment somewhere on your disk, then activate it:

    virtualenv myproject
    cd myproject
    source bin/activate

Now you can install the related required packages:

    pip install ioc

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »